@@ -329,7 +329,7 @@ class Generator:
         return f"PARTITION({keys}) "
 
     def insert_sql(self, expression):
-        kind = "OVERWRITE" if expression.args.get("overwrite") else "INTO"
+        kind = "OVERWRITE TABLE" if expression.args.get("overwrite") else "INTO"
         this = self.sql(expression, "this")
         exists = " IF EXISTS " if expression.args.get("exists") else " "
         partition_sql = (
@@ -339,7 +339,7 @@ class Generator:
         )
         expression_sql = self.sql(expression, "expression")
         sep = self.sep(sep="") if partition_sql else ""
-        return f"INSERT {kind} TABLE {this}{exists}{partition_sql}{sep}{expression_sql}"
+        return f"INSERT {kind} {this}{exists}{partition_sql}{sep}{expression_sql}"
 
     def intersect_sql(self, expression):
         return self.set_operation(
